@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2022 jrnl contributors
+# Copyright © 2012-2022 jrnl contributors
 # License: https://www.gnu.org/licenses/gpl-3.0.html
 
 from enum import Enum
@@ -198,6 +198,13 @@ class MsgText(Enum):
         Configuration updated to newest version at {config_path}
         """
 
+    ConfigDoubleKeys = """
+        There is at least one duplicate key in your configuration file.
+
+        Details:
+        {error_message}
+        """
+
     # --- Password --- #
     Password = "Password:"
     PasswordFirstEntry = "Enter password for journal '{journal_name}': "
